==================
AnkiVim
==================
|Build Status|
|Health_|
|Coverage_|
|Pypi_|


Overview
========

Use vim to rapidly write textfiles immediately importable into anki(1).

Requirements
============
* Python >= 2.7 or Python >= 3.4

Installation
============

Simply run:

.. code-block:: python

    pip install AnkiVim


You can verify that this step succeeded and see available options by running:

.. code-block:: python

    anki-vim -h


Generating Anki Cards
=====================

1. Call: 

.. code-block:: python

    anki-vim DECKNAME

2. vim starts with a preformatted card.
   Start typing the front part of the anki card below "QUESTION", then fill out 
   the back below "ANSWER". 
   (*NOTE*: It is important to leave the QUESTION and ANSWER headers intact throughout)

3. save the file and exit the editor. (vim: ":wq") => the card contents are saved to: 
   `$HOME/.ankivim/decks/DECKNAME/raw_cards.txt`.
   (alternatively, you can specify a custom location for your decks using 
   the `--deckpath` option of `script/anki-vim.py`.)

4. editor starts right back up to generate a new card for the same deck => Iterate 2.-4. until all cards are generated.

5. to stop the card creation process, simply close your editor ( for vim: ":q" or ":q!", for additional information see
   `this book <https://www.amazon.com/How-Exit-Vim-Chris-Worfolk-ebook/dp/B01N5M1U6W>`_)

Importing into Anki
=====================

Procedure to import anki cards generated by this tool into anki:

1. Open Anki

2. Generate the deck to import into or click on an existing deck

3. Click import and navigate to
   "/path/to/anki-vim/decks/DECKNAME/raw_cards.txt"

4. check "allow html in fields"

5. Done


Supports:
=========
* Latex commands of any kind
* html tags of any kind (images can be included this way as well)

.. |Build Status| image:: https://travis-ci.org/MFreidank/AnkiVim.svg?branch=master
   :target: https://travis-ci.org/MFreidank/AnkiVim

.. |Coverage_| image:: https://coveralls.io/repos/github/MFreidank/AnkiVim/badge.svg
   :target: https://coveralls.io/github/MFreidank/AnkiVim
   :alt: Coverage

.. |Health_| image:: https://api.codacy.com/project/badge/Grade/d0d6624881c0415fb72999e355741e2b    
   :target: https://www.codacy.com/app/MFreidank/AnkiVim?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=MFreidank/AnkiVim&amp;utm_campaign=Badge_Grade
   :alt: Health

.. |Pypi_| image:: https://badge.fury.io/py/AnkiVim.svg
    :target: https://badge.fury.io/py/AnkiVim
